#ifndef _EFL_CANVAS_SURFACE_TBM_EO_H_
#define _EFL_CANVAS_SURFACE_TBM_EO_H_

#ifndef _EFL_CANVAS_SURFACE_TBM_EO_CLASS_TYPE
#define _EFL_CANVAS_SURFACE_TBM_EO_CLASS_TYPE

typedef Eo Efl_Canvas_Surface_Tbm;

#endif

#ifndef _EFL_CANVAS_SURFACE_TBM_EO_TYPES
#define _EFL_CANVAS_SURFACE_TBM_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Native Tizen Buffer Manager surface for Efl canvas
 *
 * @ingroup Efl_Canvas_Surface_Tbm
 */
#define EFL_CANVAS_SURFACE_TBM_CLASS efl_canvas_surface_tbm_class_get()

EWAPI const Efl_Class *efl_canvas_surface_tbm_class_get(void);
#endif /* EFL_BETA_API_SUPPORT */

#endif
